@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2010-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -38,7 +38,7 @@ public:
 	 */
 	KGpgDelSign(QObject *parent, KGpgSignNode *signid);
 
-    ~KGpgDelSign() override;
+	~KGpgDelSign() override = default;
 
 	/**
 	 * @brief set the ids to delete
