@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008, 2009, 2010 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -41,7 +41,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgImport() override;
+	~KGpgImport() override = default;
 
 	/**
 	 * @brief get the names and short fingerprints of the imported keys
